# mamba-json-formatter
JSON formatter for [https://github.com/nestorsalceda/mamba](mamba)


## Upload to pypi

```bash
python -m pip install build twine
python -m build
python -m twine upload --repository testpypi dist/*
```